@@ -2,7 +2,7 @@ package Term::Caca;
 
 require Exporter;
 require DynaLoader;
-$VERSION = '0.96';
+$VERSION = '0.97';
 @ISA = qw(Exporter DynaLoader);
 Term::Caca->bootstrap($VERSION);
 
@@ -232,7 +232,7 @@ sub draw_ellipse {
 #
 sub draw_thin_ellipse {
   my ($self, $x0, $y0, $ra, $rb) = @_;
-  _draw_ellipse($x0, $y0, $ra, $rb);
+  _draw_thin_ellipse($x0, $y0, $ra, $rb);
 }
 
 #
@@ -472,19 +472,37 @@ a constant frame rate
 
 =head3 clear
 
-=head3 draw_line
+=head3 draw_line( $x1, $y1, $x2, $y2, $char )
+
+Draws a line from I<($x1,$y2)> to I<($x2,$y2)>
+using the character I<$char>.
+
+=head3 draw_thin_line( $x1, $y1, $x2, $y2 )
+
+Draws a line from I<($x1,$y2)> to I<($x2,$y2)>
+using ascii art.
 
 =head3 draw_polyline
 
-=head3 draw_thin_line
 
 =head3 draw_thin_polyline
 
-=head3 draw_circle
+=head3 draw_circle( $x, $y, $r, $char );
 
-=head3 draw_ellipse
+Draws a circle centered at I<($x,$y)> with a radius
+of I<$r> using the character I<$char>.
 
-=head3 draw_thin_ellipse
+=head3 draw_ellipse( $x, $y, $radius_x, $radius_y, $char )
+
+Draws an ellipse centered at I<($x,$y)> with an x-axis
+radius of I<$radius_x> and a y-radius of I<$radius_y>
+using the character I<$char>.
+
+=head3 draw_thin_ellipse( $x, $y, $radius_x, $radius_y )
+
+Draws an ellipse centered at I<($x,$y)> with an x-axis
+radius of I<$radius_x> and a y-radius of I<$radius_y>
+using ascii art.
 
 =head3 fill_ellipse
 
@@ -550,8 +568,6 @@ John Beppu E<lt>beppu@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Tie::Array::Pointer|Tie::Array::Pointer>,
-
 L<Term::Caca::Constants|Term::Caca::Constants>,
 L<Term::Caca::Sprite|Term::Caca::Sprite>,
 L<Term::Caca::Bitmap|Term::Caca::Bitmap>,
