@@ -1,6 +1,7 @@
 package Term::Caca::Sprite;
 
 use strict;
+use warnings;
 use Term::Caca;
 
 sub new {
@@ -113,6 +114,12 @@ B<Example>:
 
 B<Example>:
 
+=head2 draw
+
+...
+
+B<Example>:
+
 =head2 DESTROY
 
 ...
